@@ -298,15 +298,13 @@ def image(
     prof_kws=None,
     thresh=None,
     thresh_type="abs",
-    contour=False,
-    contour_kws=None,
-    return_mesh=False,
     fill_value=None,
     mask_zero=False,
     floor=None,
-    rms_ellipse=None,
+    rms_ellipse=False,
     rms_ellipse_kws=None,
     divide_by_max=False,
+    return_mesh=False,
     **plot_kws,
 ):
     """Plot a 2D image.
@@ -327,8 +325,6 @@ def image(
         Set elements below this value to zero.
     thresh_type : {'abs', 'frac'}
         If 'frac', `thresh` is a fraction of the maximum element in `f`.
-    return_mesh : bool
-        Whether to return a mesh from `ax.pcolormesh`.
     fill_value : float
         If not None, fills in masked values of `f`.
     mask_zero : bool
@@ -339,8 +335,10 @@ def image(
         Whether to plot rms ellipse.
     rms_ellipse_kws : dict
         Key word arguments for `image_rms_ellipse`.
-    divide_by_mas : bool
+    divide_by_max : bool
         Whether to divide the image by its maximum element.
+    return_mesh : bool
+        Whether to return a mesh from `ax.pcolormesh`.
     **plot_kws
         Key word arguments for `ax.pcolormesh`.
     """
@@ -648,7 +646,7 @@ def corner(
                 else:
                     profx = profy = prof
                 _image = psi.project(data, (j, ii + 1))
-                _image = _image / np.max(image)
+                _image = _image / np.max(_image)
                 ax, mesh = image(
                     _image,
                     x=coords[j],
@@ -757,10 +755,11 @@ def slice_matrix(
     gap=2.0,
     pad=0.0,
     fig_kws=None,
-    annotate=True,
-    label_height=0.22,
     plot_marginals=True,
     plot_kws_marginal_only=None,
+    return_indices=False,
+    annotate=True,
+    label_height=0.22,
     debug=False,
     **plot_kws,
 ):
@@ -809,25 +808,28 @@ def slice_matrix(
         the shape=10 and pad=0.1, we would start from 1 and end at 9.
     fig_kws : dict
         Key word arguments for `pplt.subplots`.
-    annotate : bool
-        Whether to add dimension labels/arrows to the figure.
     plot_marginals : bool
         Whether to plot the 3D and 2D marginal distributions.
     plot_kws_marginal_only : dict
         Key word arguments for the lower-left and upper-right panels, which
         plot the 3D marginal distributions.
-    debug : bool
-        Whether to print debugging messages.
+    return_indices : bool
+        Whether to return the slice indices.
     annotate : bool
-        Whether to label the axes.
+        Whether to add dimension labels/arrows to the figure.
     label_height : float
         Tweaks the position of the slice dimension labels.
+    debug : bool
+        Whether to print debugging messages.
     **plot_kws
         Key word arguments for `image`.
 
     Returns
     -------
-    axes
+    axes : Axes
+        The plot axes.
+    ind_slice : 2-tuple of lists (optional)
+        The slice indices along `axis_slice`. Returned if `return_indices` is True.
     """
     # Setup
     # -------------------------------------------------------------------------
@@ -864,6 +866,7 @@ def slice_matrix(
         _pad = int(_pad * s)
         ii = np.linspace(_pad, s - 1 - _pad, n).astype(int)
         ind_slice.append(ii)
+    ind_slice = tuple(ind_slice)
 
     if debug:
         print("Slice indices:")
@@ -1014,6 +1017,8 @@ def slice_matrix(
                 xytext=(1.0 + label_height, 0.5 + arrow_direction * text_length),
                 **annotate_kws,
             )
+    if return_indices:
+        return axes, ind_slice
     return axes
 
 
