@@ -25,6 +25,8 @@ def random_selection(array, k):
 
     If 0 < k < 1, we select `k * len(array)` elements.
     """
+    if type(array) in (list, tuple):
+        array = np.array(array)
     if k is None:
         return array
     if k < 0 or k >= array.shape[0]:
